import React, { useState } from 'react';
import { View } from 'react-native';
// material
import { Surface, Text, TouchableRipple } from 'react-native-paper';
import MaterialCommunityIcons from 'react-native-vector-icons/MaterialCommunityIcons';
// redux
import { useDispatch } from 'react-redux';
import { useDeviceList, useDeviceActive, useReports, useSelectedReport } from '../provider/device.helper';
// dialog
import { DialogDevices } from '../dialog/devices';
// core
import { Storage } from '../core/storage';
import { DialogReports } from '../dialog/reports';

export const Selection = () => {
	const dispatch = useDispatch();

	const [devices] = useDeviceList();
	const [deviceActive, setDeviceActive] = useDeviceActive(dispatch);
	const [reports] = useReports();
	const [selectedReport, setSelectedReport] = useSelectedReport(dispatch);

	const [showDevicesDialog, setShowDevicesDialog] = useState(false);
	const [showReportsDialog, setShowReportsDialog] = useState(false);

	const onDevicesDialogClose = async (index) => {
		setShowDevicesDialog(false);

		if (index !== -1 && index !== deviceActive) {
			setDeviceActive(index);
			Storage.SetDeviceActive(index);
		}
	};

	const onReportsDialogClose = async (index) => {
		setShowReportsDialog(false);

		if (index !== -1 && index !== selectedReport) {
			setSelectedReport(index);
		}
	};

	const ItemView = ({ children, title }) => (
		<View
			style={{
				display: 'flex',
				flexWrap: 'nowrap',
				flexDirection: 'row',
				alignItems: 'center',
				paddingHorizontal: 12,
				paddingVertical: 8,
				borderBottomWidth: 1,
				borderStyle: 'solid',
				borderBottomColor: 'rgba(0, 0, 0, 0.12)',
			}}>
			<Text style={{ fontFamily: 'font-bold' }}>{title}</Text>
			<View style={{ flex: 1 }} />
			{children}
		</View>
	);

	const SelectView = ({ value, onPress }) => (
		<TouchableRipple onPress={onPress} style={{ flexDirection: 'row' }}>
			<>
				<Text style={{ width: 120, color: value ? '#343536' : '#9e9e9e', fontSize: 12 }}>
					{value ?? 'انتخاب کنید'}
				</Text>
				<MaterialCommunityIcons name="menu-down" size={20} color="#9e9e9e" />
			</>
		</TouchableRipple>
	);

	return (
		<>
			{reports &&
				reports.length !== 0 &&
				selectedReport !== -1 &&
				reports[selectedReport] &&
				reports[selectedReport].copyright.length != 0 && (
					<Surface style={{ backgroundColor: '#d50000', paddingHorizontal: 16, paddingBottom: 8 }}>
						<Text style={{ color: 'rgba(255, 255, 255, 0.9)' }}>
							{reports[selectedReport].copyright}
						</Text>
					</Surface>
				)}
			<Surface style={{ backgroundColor: '#fff' }}>
				<ItemView title="انتخاب دستگاه">
					<SelectView
						value={
							deviceActive !== -1 && devices[deviceActive] ? devices[deviceActive].name : null
						}
						onPress={() => setShowDevicesDialog(true)}
					/>
				</ItemView>
				{reports && reports.length !== 0 ? (
					<>
						<ItemView title="تاریخ گزارشات">
							<SelectView
								value={
									selectedReport !== -1 && reports[selectedReport]
										? reports[selectedReport].date
										: null
								}
								onPress={() => setShowReportsDialog(true)}
							/>
						</ItemView>
						<ItemView title="نوع گزارش">
							<Text style={{ width: 140, fontSize: 12 }}>
								{selectedReport !== -1 && reports[selectedReport]
									? reports[selectedReport].type
									: null}
							</Text>
						</ItemView>
					</>
				) : (
					<></>
				)}
			</Surface>

			<DialogDevices
				visible={showDevicesDialog}
				onClose={onDevicesDialogClose}
				devices={devices}
				active={deviceActive}
			/>

			<DialogReports
				visible={showReportsDialog}
				onClose={onReportsDialogClose}
				reports={reports}
				selected={selectedReport}
			/>
		</>
	);
};
