import dynamic from '../dynamic';

/**
 * Convert selected report and use dynamic data to readable data
 * @param {{day: string, date: string, data: { status: boolean, key: string, value: string | undefined }[]}} report selected report
 * @returns {{status: boolean, icon: any, label: string}[]}
 */
export const useDynamic = (report) => {
	try {
		let output = [];
		console.log(report);
		for (let item of report.data) {
			console.log(item);
			let config = getDynamicByKey(item.key);
			if (config) {
				let _output = {
					status: item.status,
					icon: '',
					label: config.translate,
				};

				if (config.type === 'icon') {
					_output.icon = item.status ? config.iconok : config.iconerr;
				}
			}
		}

		console.log(output);

		return output;
	} catch (error) {
		console.error('Dynamic.js');
		console.error(error);
		return [];
	}
};

/**
 * get dynamic config by report data key
 * @param {string} key
 * @return {undefined | { type: 'icon' | 'icondouble', key: string, translate: string, iconok: any, iconerr: any }}
 */
const getDynamicByKey = (key) => {
	return dynamic.find((item) => key.includes(item.translate));
};
