import SmsAndroid from '../module/sms';

export const Request = new (class {
	/**
	 * Send Reset IP via sms
	 * @param {string} phone device phone number
	 * @returns {Promise<void>}
	 */
	SendResetIP(phone) {
		return this._send(phone, 'RESET-IP');
	}

	/**
	 * Send Alarm off via sms
	 * @param {string} phone  device phone number
	 * @returns {Promise<void>}
	 */
	SendAlarmOff(phone) {
		return this._send(phone, 'ALARM-OFF');
	}

	/**
	 * Send Alarm on via sms
	 * @param {string} phone  device phone number
	 * @returns {Promise<void>}
	 */
	SendAlarmOn(phone) {
		return this._send(phone, 'ALARM-ON');
	}

	/**
	 * Send Alarm set checks
	 * @param {string} phone device phone number
	 * @param {string} value checks value
	 * @returns {Promise<void>}
	 */
	SendAlarmSet(phone, value) {
		return this._send(phone, `ALARMSET=${value}`);
	}

	/**
	 *  Send Reset data to device
	 * @param {string} phone device phone number
	 * @returns {Promise<void>}
	 */
	SendResetData(phone) {
		return this._send(phone, 'GET');
	}

	/**
	 * @see false
	 * @param {*} phone
	 * @param {*} message
	 * @returns
	 */
	_send(phone, message) {
		return new Promise((resolve, reject) => {
			SmsAndroid.autoSend(
				phone,
				message,
				() => {
					console.error('REJECT SEND SMS');
					reject();
				},
				() => {
					console.log('RESOLVED SEND SMS');
					resolve();
				}
			);
		});
	}
})();
