import AsyncStorage from '@react-native-async-storage/async-storage';

class CStorage {
	/**
	 * Get list of devices from storage
	 * @returns {[{name: string, phone: string}]} List of devices from storage
	 */
	async ListDevice() {
		try {
			const device = await AsyncStorage.getItem('device');
			return device != null ? JSON.parse(device) : [];
		} catch (error) {
			return [];
		}
	}

	/**
	 * Set device to stronge
	 * @param {[{name: string, phone: string}]} devices list of devices
	 * @returns {null|any} Save device to storage error
	 */
	async SetDevice(devices) {
		try {
			await AsyncStorage.setItem('device', JSON.stringify(devices));
			return null;
		} catch (error) {
			return error;
		}
	}

	/**
	 * Set active device by index in storage
	 * @param {number} index Device index in array
	 * @returns {null|any} Save active device in storage error
	 */
	async SetDeviceActive(index) {
		try {
			await AsyncStorage.setItem('device:active', index.toString());
			return null;
		} catch (error) {
			return error;
		}
	}

	/**
	 * Get active device index in storage
	 * @returns {number} Active device index
	 */
	async GetDeviceActive() {
		try {
			const index = await AsyncStorage.getItem('device:active');
			// eslint-disable-next-line radix
			return index !== null ? parseInt(index) : -1;
		} catch (error) {
			return -1;
		}
	}
}

export const Storage = new CStorage();
