import React, { useEffect, useState } from 'react';
import { View } from 'react-native';
import { Button, Text, TextInput, Dialog, Portal, Checkbox } from 'react-native-paper';

export const DialogDeviceForm = ({ visible, onClose, data }) => {
	const [name, setName] = useState('');
	const [phone, setPhone] = useState('');
	const [prefix, setPrefix] = useState(false);

	useEffect(() => {
		if (data) {
			setName(data['name']);
			setPhone(data['phone']);
			// if data phone start with +98
			if (data['phone'].slice(0, 3) === '+98') {
				setPrefix(true);
			}
		} else {
			clear();
		}
	}, [data]);

	const submit = () => {
		onClose({ name, phone, prefix });
		// clear inputs
		clear();
	};

	const close = () => {
		onClose(null);
		// clear inputs
		clear();
	};

	const clear = () => {
		setName('');
		setPhone('');
		setPrefix(false);
	};

	return (
		<Portal>
			<Dialog animationType="slide" transparent={true} visible={visible}>
				<Dialog.Title>مدیریت دستگاه</Dialog.Title>

				<Dialog.Content>
					<TextInput
						style={{ marginVertical: 10 }}
						label="نام دستگاه"
						onChangeText={setName}
						value={name}
					/>

					<TextInput
						style={{ marginVertical: 10 }}
						keyboardType="phone-pad"
						label="تلفن دستگاه"
						onChangeText={setPhone}
						value={phone}
					/>
					<View
						style={{
							marginTop: 16,
							marginVertical: 10,
							flexDirection: 'row',
							flexWrap: 'nowrap',
							alignItems: 'center',
						}}>
						<Checkbox
							status={prefix ? 'checked' : 'unchecked'}
							onPress={() => setPrefix(!prefix)}
						/>

						<Text style={{ marginLeft: 12, color: '#000' }}>پیش شماره پشتیبانی شود</Text>
					</View>
				</Dialog.Content>

				<Dialog.Actions>
					<Button style={{ width: 50 }} onPress={close} children="لغو" />
					<Button
						style={{ width: 70, marginLeft: 5 }}
						onPress={submit}
						mode="contained"
						children="ثبت"
					/>
				</Dialog.Actions>
			</Dialog>
		</Portal>
	);
};
