import React from 'react';
import { ScrollView, StyleSheet, View } from 'react-native';
// material
import { Button, Dialog, Portal, RadioButton, List, Modal, Text } from 'react-native-paper';

export const DialogReports = ({ visible, onClose, selected, reports }) => {
	return (
		<Portal>
			<Modal animationType="slide" transparent={true} visible={visible}>
				<View style={styles.container}>
					<Dialog.Title>یک گزارش را انتخاب کنید</Dialog.Title>

					{reports.length !== 0 && (
						<ScrollView style={{ maxHeight: 300 }}>
							<List.Section>
								{reports.map((item, index) => (
									<List.Item
										key={index}
										title={item.date}
										description={item.type}
										left={() => (
											<RadioButton
												value={index}
												status={index === selected ? 'checked' : 'unchecked'}
												onPress={() => onClose(index)}
											/>
										)}
									/>
								))}
							</List.Section>
						</ScrollView>
					)}

					{reports.length === 0 && (
						<Dialog.Content style={{ marginBottom: 50 }}>
							<Text>
								هیچ گزارشی یافت نشد. شاید نیاز باشد یک دستگاه را انتخاب کنید و سپس یک گزارش را
								بر گزینید.
							</Text>
						</Dialog.Content>
					)}

					<Dialog.Actions>
						<Button
							style={{ flex: 1 }}
							mode="contained"
							onPress={() => onClose(-1)}
							children="لغو"
						/>
					</Dialog.Actions>
				</View>
			</Modal>
		</Portal>
	);
};

const styles = StyleSheet.create({
	container: {
		backgroundColor: 'white',
		marginVertical: 44,
		marginHorizontal: 26,
		elevation: 24,
		justifyContent: 'flex-start',
		borderRadius: 6,
	},
});
