import { useSelector } from 'react-redux';
import { ReduxDevice } from './device';

/**
 * use device list to get and set state
 * @returns {[{name: string, phone: string}[], (value: {name: string, phone: string}[]): void]}
 */
export const useDeviceList = (dispatch) => {
	return [
		useSelector((state) => state.Device).list,
		(value) => {
			dispatch(ReduxDevice.setList(value));
		},
	];
};

/**
 * use device active to get and set active device index state
 * @returns {[number, (index: number)=> void]}
 */
export const useDeviceActive = (dispatch) => {
	return [
		useSelector((state) => state.Device).active,
		(value) => {
			dispatch(ReduxDevice.setActive(value));
		},
	];
};

/**
 * use reports from sms
 * @returns {[{day: string, date: string, type: string, copyright: string, data: { status: boolean | null, key: string, value: string | undefined }[]}[], (data: {day: string, date: string, type: string, copyright: string, data: { status: boolean, key: string, value: string | undefined }[]}[]) => void]}
 */
export const useReports = (dispatch) => {
	return [
		useSelector((state) => state.Device).reports,
		(value) => {
			dispatch(ReduxDevice.setReports(value));
		},
	];
};

/**
 * use selected report
 * @returns {number, (index: number): void}
 */
export const useSelectedReport = (dispatch) => {
	return [
		useSelector((state) => state.Device).selected,
		(value) => {
			dispatch(ReduxDevice.setSelectedReport(value));
		},
	];
};
