import React, { useEffect, useState } from 'react';
import { View, Dimensions } from 'react-native';
import GestureRecognizer from 'react-native-swipe-gestures';
// material
import { AnimatedFAB } from 'react-native-paper';
/// views
import { Rack } from '../Rack';
import { More } from '../More';
// redux
import { useReports, useSelectedReport } from '../../provider/device.helper';

const { height, width } = Dimensions.get('window');

export const Information = () => {
	const [view, setView] = useState(false);
	const [colors, setColors] = useState(['#ffc107', '#ffc107']);
	const [reports] = useReports();
	const [index] = useSelectedReport();

	const toggleView = () => setView(!view);

	const config = {
		velocityThreshold: 0.3,
		directionalOffsetThreshold: 80,
	};

	useEffect(() => {
		if (!reports || !reports[index]) return;
		if (reports[index].type == 'خطا') {
			// set both colors to red
			setColors(['#e53935', '#e53935']);
			return;
		}
		let error = [false, false];
		// set both colors to amber
		setColors(['#ffc107', '#ffc107']);
		for (let item of reports[index].data) {
			if (item.status == false && !item.key.startsWith('رک')) {
				error[1] = true;
			}
			if (item.status == false && item.key.startsWith('رک')) {
				error[0] = true;
			}
		}

		setColors([error[0] ? '#e53935' : '#4caf50', error[1] ? '#e53935' : '#4caf50']);
		console.log(colors);
	}, [index]);

	return (
		<>
			<GestureRecognizer
				style={{ flex: 1 }}
				config={config}
				onSwipeDown={toggleView}
				onSwipeUp={toggleView}>
				<View style={{ display: view ? 'flex' : 'none', height: height - 168 }}>
					<More />
				</View>
				<View style={{ display: view ? 'none' : 'flex', height: height - 168 }}>
					<Rack />
				</View>
			</GestureRecognizer>

			<AnimatedFAB
				extended={true}
				style={{
					position: 'absolute',
					bottom: 16,
					right: width / 2 - 85,
					backgroundColor: view ? colors[0] : colors[1],
				}}
				label="اطلاعات بیشتر"
				icon={view ? 'menu-up' : 'menu-down'}
				onPress={() => setView(!view)}
			/>
		</>
	);
};
