import React, { useEffect, useState } from 'react';
import { View } from 'react-native';
// material
import { Text, Card } from 'react-native-paper';
// redux
import { useReports, useSelectedReport } from '../../provider/device.helper';

// const images = require.context('../../icon/', true);

export const More = () => {
	const [reports] = useReports();
	const [index] = useSelectedReport();
	const [empty, setEmpty] = useState(false);

	useEffect(() => {
		if (reports && reports[index]) {
			if (
				reports[index].data == 0 ||
				reports[index].data.filter(
					(item) =>
						item.key.startsWith('رک') == false || ['دما', 'رطوبت'].includes(item.key) == false
				).length == 0
			)
				setEmpty(true);
		}
	}, [index]);

	const Item = ({ status, label, value }) => {
		return (
			<Card
				style={{
					width: 120,
					maxHeight: 75,
					margin: 5,
					backgroundColor: status ? '#00c853' : label.startsWith('کولر') ? '#2196f3' : '#f44336',
				}}>
				<Card.Content style={{ justifyContent: 'center', alignItems: 'center' }}>
					<Text style={{ color: status ? '#424242' : '#fff' }}>{label ?? ''}</Text>
					{value && value.length !== 0 ? (
						<Text style={{ fontSize: 12, color: status ? '#424242' : '#fff' }}>
							{value.toString() ?? ''}
						</Text>
					) : (
						<></>
					)}
				</Card.Content>
			</Card>
		);
	};

	return reports && reports[index] ? (
		empty ? (
			<View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
				<Text>هیچ اطلاعات محیطی برای این گزارش وجود ندارد.</Text>
				<Text>برای گزارشات بیشتر بر روی دکمه "اطلاعات بیشتر" کلیک کنید.</Text>
			</View>
		) : (
			<View
				style={{
					flex: 1,
					flexWrap: 'wrap',
					flexDirection: 'row',
					justifyContent: 'center',
					marginTop: 12,
				}}>
				{reports[index].data.map((item, i) => {
					if (item.key.startsWith('رک') || ['دما', 'رطوبت'].includes(item.key)) {
						return <View />;
					}
					const value = item.value;
					const label = item.key;

					if (item.status == null) {
						let firstValue = false,
							secondValue = false;

						if (item.value === '0') {
							// both are off
						} else if (item.value === '1') {
							firstValue = true; // first one is on and second is off
						} else if (value === '2') {
							secondValue = true; // second on is on and first is off
						} else {
							// both are on
							firstValue = true;
							secondValue = true;
						}

						return (
							<>
								<Item
									key={`${i}/1`}
									status={firstValue}
									label={`${label} 1`}
									value={firstValue ? 'روشن' : 'خاموش'}
								/>
								<Item
									key={`${i}/2`}
									status={secondValue}
									label={`${label} 2`}
									value={secondValue ? 'روشن' : 'خاموش'}
								/>
							</>
						);
					}

					return <Item key={i} status={item.status} label={label} value={value} />;
				})}
			</View>
		)
	) : (
		<View style={{ padding: 20, flex: 1 }}>
			<Text>
				هیچ گزارشی یافت نشد. شاید نیاز باشد یک دستگاه را انتخاب کنید و سپس یک گزارش را بر گزینید.
			</Text>
		</View>
	);
};
