import React, { useEffect, useState } from 'react';
import { View, Dimensions } from 'react-native';
// material
import { Text, Card } from 'react-native-paper';
// redux
import { useReports, useSelectedReport } from '../../provider/device.helper';

const { width } = Dimensions.get('window');

export const Rack = () => {
	const [reports] = useReports();
	const [index] = useSelectedReport();
	const [empty, setEmpty] = useState(false);

	useEffect(() => {
		if (reports && reports[index]) {
			if (
				reports[index].data.length == 0 ||
				reports[index].data.filter(
					(item) => item.key.startsWith('رک') || ['دما', 'رطوبت'].includes(item.key)
				).length == 0
			)
				setEmpty(true);
			else setEmpty(false);
		}
	}, [index]);

	const Item = ({ label, value, status, styles }) => (
		<Card style={{ margin: 4, backgroundColor: status ? '#ffffff' : '#f44336', ...styles }}>
			<Card.Content>
				<Text style={{ fontFamily: 'font', fontSize: 20 }}>{value}</Text>
				<Text style={{ color: 'rgba(0, 0, 0, 0.5)', fontSize: 12 }}>{label}</Text>
			</Card.Content>
		</Card>
	);

	const Items = ({ children, style }) => (
		<View
			style={{
				flex: 1,
				flexWrap: 'wrap',
				flexDirection: 'row',
				marginHorizontal: 12,
				marginVertical: 4,
				...style,
			}}>
			{children}
		</View>
	);

	return reports && reports[index] ? (
		empty ? (
			<View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
				<Text>هیچ اطلاعات محیطی برای این گزارش وجود ندارد.</Text>
				<Text>برای گزارشات بیشتر بر روی دکمه "اطلاعات بیشتر" کلیک کنید.</Text>
			</View>
		) : (
			<View style={{ flex: 1 }}>
				<Text style={{ margin: 8 }}>محیط</Text>
				<Items style={{ maxHeight: 85 }}>
					{reports[index].data.findIndex((item) => item.key === 'دما') != -1 && (
						<Item
							styles={{ minWidth: 120, width: width / 2 - 22 }}
							label="دما محیط"
							value={`${reports[index].data.find((item) => item.key === 'دما').value} C`}
							status={reports[index].data.find((item) => item.key === 'دما').status}
						/>
					)}
					{reports[index].data.findIndex((item) => item.key === 'رطوبت') != -1 && (
						<Item
							styles={{ minWidth: 120, width: width / 2 - 22 }}
							label="رطوبت محیط"
							value={`${reports[index].data.find((item) => item.key === 'رطوبت').value}`}
							status={reports[index].data.find((item) => item.key === 'رطوبت').status}
						/>
					)}
				</Items>
				<Text style={{ margin: 8 }}>رک ها</Text>
				<Items>
					{reports[index].data
						.filter((item) => item.key.startsWith('رک'))
						.map((item, i) => (
							<Item
								key={i}
								styles={{ minWidth: width / 3 - 16, maxWidth: width / 3 - 16, maxHeight: 80 }}
								label={`دما ${item.key}`}
								value={`${item.value} C`}
								status={item.status}
							/>
						))}
				</Items>
			</View>
		)
	) : (
		<View style={{ padding: 20, flex: 1 }}>
			<Text>
				هیچ گزارشی یافت نشد. شاید نیاز باشد یک دستگاه را انتخاب کنید و سپس یک گزارش را بر گزینید.
			</Text>
		</View>
	);
};
